==> apb-project_2.12-2.2.0-sources.jar: org/mulesoft/apb/project/internal/emitter/ProjectSummaryInstanceEmitter.scala <==
package org.mulesoft.apb.project.internal.emitter

import amf.core.internal.render.emitters.PartEmitter
import amf.shapes.client.scala.model.domain.jsonldinstance.JsonLDObject
import org.mulesoft.apb.project.client.scala.extensions.EnvironmentExtension
import org.mulesoft.apb.project.client.scala.model.project.management.APIInstance
import org.mulesoft.apb.project.internal.emitter.EmitterUtils.emitScalarField
import org.mulesoft.common.client.lexical.Position
import org.yaml.model.YDocument.{EntryBuilder, PartBuilder}
import org.yaml.model.YNode

class ProjectSummaryInstanceEmitter(instance: APIInstance) extends PartEmitter {
  override def emit(partBuilder: PartBuilder): Unit = {
    partBuilder.obj { entryBuilder: EntryBuilder =>
      // Instance id transformed to String to keep compatibility to JSON-LD summary
      instance.instanceId.foreach(id => entryBuilder.entry(YNode("id"), YNode(id.toString)))
      instance.instanceLabel.foreach(id => entryBuilder.entry(YNode("label"), YNode(id)))
      instance.consumerEndpoint.foreach(endpoint => entryBuilder.entry(YNode("consumerEndpoint"), YNode(endpoint)))
      instance.hasApprovedContracts.foreach(hasApprovedContracts =>
        entryBuilder.entry(YNode("hasApprovedContracts"), YNode(hasApprovedContracts))
      )

      EnvironmentExtension.extractFromInstance(instance).map { environment =>
        entryBuilder.entry(
            YNode("environment"),
            partBuilder => ProjectSummaryEnvironmentEmitter(environment).emit(partBuilder)
        )
      }
    }
  }

  override def position(): Position = Position.ZERO
}

object ProjectSummaryInstanceEmitter {
  def apply(instance: JsonLDObject) = new ProjectSummaryInstanceEmitter(APIInstance(instance))
}

==> apb-project_2.12-2.2.4-sources.jar: org/mulesoft/apb/project/internal/emitter/ProjectSummaryInstanceEmitter.scala <==
package org.mulesoft.apb.project.internal.emitter

import amf.core.internal.render.emitters.PartEmitter
import amf.shapes.client.scala.model.domain.jsonldinstance.JsonLDObject
import org.mulesoft.apb.project.client.scala.extensions.EnvironmentExtension
import org.mulesoft.apb.project.client.scala.model.project.management.APIInstance
import org.mulesoft.apb.project.internal.emitter.EmitterUtils.emitScalarField
import org.mulesoft.common.client.lexical.Position
import org.yaml.model.YDocument.{EntryBuilder, PartBuilder}
import org.yaml.model.YNode

class ProjectSummaryInstanceEmitter(instance: APIInstance) extends PartEmitter {
  override def emit(partBuilder: PartBuilder): Unit = {
    partBuilder.obj { entryBuilder: EntryBuilder =>
      // Instance id transformed to String to keep compatibility to JSON-LD summary
      instance.instanceId.foreach(id => entryBuilder.entry(YNode("id"), YNode(id.toString)))
      instance.instanceLabel.foreach(id => entryBuilder.entry(YNode("label"), YNode(id)))
      instance.status.foreach(id => entryBuilder.entry(YNode("status"), YNode(id.toString)))
      instance.organizationId.foreach(id => entryBuilder.entry(YNode("organizationId"), YNode(id)))
      instance.consumerEndpoint.foreach(endpoint => entryBuilder.entry(YNode("consumerEndpoint"), YNode(endpoint)))
      instance.hasApprovedContracts.foreach(hasApprovedContracts =>
        entryBuilder.entry(YNode("hasApprovedContracts"), YNode(hasApprovedContracts))
      )

      EnvironmentExtension.extractFromInstance(instance).map { environment =>
        entryBuilder.entry(
            YNode("environment"),
            partBuilder => ProjectSummaryEnvironmentEmitter(environment).emit(partBuilder)
        )
      }
    }
  }

  override def position(): Position = Position.ZERO
}

object ProjectSummaryInstanceEmitter {
  def apply(instance: JsonLDObject) = new ProjectSummaryInstanceEmitter(APIInstance(instance))
}
